/**
* @addtogroup IO
* @{
*
* @brief Provides data structures and functions for performing input/output (I/O) operations, such as printf and scanf.
*
* @since 1.0
* @version 1.0
*/

/**
* @file aio.h
*
* @brief Declares functions related to asynchronous I/O (AIO) operations.
*
* @since 1.0
* @version 1.0
*/

#ifndef _AIO_H
#define _AIO_H

#ifdef __cplusplus
extern "C" {
#endif

#include <signal.h>
#include <time.h>

/**@brief Waiting to be notified of the completion of all asynchronous I/O operations */
#define LIO_WAIT 0
/**@brief Not waiting to be notified of the completion of all asynchronous I/O operations */
#define LIO_NOWAIT 1

/**
* @brief Initiates AIO requests.
* @param mode Indicates the mode of notification upon the completion of AIO operations.
* @param cbs Indicates the pointer to an array of pointers to the <b>aiocb</b> structure.
* @param cnt Indicates the array size.
* @param sev Indicates the asynchronous notification mode. The value <b>NULL</b> indicates that a notification is not required.
* @return Returns <b>0</b> if the operation is successful; returns <b>-1</b> and sets <b>errno</b> to a value in the following table if the operation fails.
* errno | Description
* -------|---------
* EAGAIN | Insufficient resources
* @since 1.0
* @version 1.0
*/
int lio_listio(int mode, struct aiocb *restrict const *restrict cbs, int cnt, struct sigevent *restrict sev);

#ifdef __cplusplus
}
#endif

#endif

/** @} */