/**
* @addtogroup UTILS
* @{
*
* @brief Provides functions and data structures related to system operations, such as string conversion and I/O, string operations, process operations and so on.
*
* @since 1.0
* @version 1.0
*/

/**
* @file errno.h
*
* @brief Defines error codes.
*
* You can view the value of {@link errno} to check the error code definition in this file to preliminarily locate the fault. \n
* @since 1.0
* @version 1.0
*/

/**@brief Operation not permitted */
#define EPERM            1
/**@brief No such file or path */
#define ENOENT           2
/**@brief No such process */
#define ESRCH            3
/**@brief Interrupted function call */
#define EINTR            4
/**@brief I/O error */
#define EIO              5
/**@brief No such device or address */
#define ENXIO            6
/**@brief Parameter list too long */
#define E2BIG            7
/**@brief Exec format error */
#define ENOEXEC          8
/**@brief Bad file descriptor */
#define EBADF            9
/**@brief No child processes */
#define ECHILD          10
/**@brief Retry */
#define EAGAIN          11
/**@brief Not enough memory space */
#define ENOMEM          12
/**@brief Incorrect permission */
#define EACCES          13
/**@brief Invalid address */
#define EFAULT          14
/**@brief Block device request */
#define ENOTBLK         15
/**@brief Device or resource busy */
#define EBUSY           16
/**@brief File exists */
#define EEXIST          17
/**@brief Incorrect link */
#define EXDEV           18
/**@brief No such device */
#define ENODEV          19
/**@brief Not a directory */
#define ENOTDIR         20
/**@brief Is a directory */
#define EISDIR          21
/**@brief Invalid parameter */
#define EINVAL          22
/**@brief Too many opened files in system (the maximum number exceeded) */
#define ENFILE          23
/**@brief Too many opened files in a process (the maximum number exceeded) */
#define EMFILE          24
/**@brief Inappropriate I/O control operation */
#define ENOTTY          25
/**@brief Text file busy */
#define ETXTBSY         26
/**@brief File too large */
#define EFBIG           27
/**@brief No space left on device */
#define ENOSPC          28
/**@brief Invalid query */
#define ESPIPE          29
/**@brief Read-only file system */
#define EROFS           30
/**@brief Too many links */
#define EMLINK          31
/**@brief The pipe file is incorrect or the read end of the pipe is closed during the write operation. */
#define EPIPE           32
/**@brief Domain error. The value of at least one input parameter is out of the parameter range. */
#define EDOM            33
/** @brief The actual return value exceeds the return value range. */
#define ERANGE          34
/**@brief Resource deadlock */
#define EDEADLK         35
/**@brief File name too long */
#define ENAMETOOLONG    36
/**@brief No locks available */
#define ENOLCK          37
/**@brief Function not implemented */
#define ENOSYS          38
/**@brief Directory not empty */
#define ENOTEMPTY       39
/**@brief Too many levels of symbolic links */
#define ELOOP           40
/**@brief Operation would block (the same value as {@link EAGAIN}) */
#define EWOULDBLOCK     EAGAIN
/**@brief No message of the desired type */
#define ENOMSG          42
/**@brief Identifier removed */
#define EIDRM           43
/**@brief Channel number out of range */
#define ECHRNG          44
/**@brief Level 2 not synchronized */
#define EL2NSYNC        45
/**@brief Level 3 halted */
#define EL3HLT          46
/**@brief Level 3 reset */
#define EL3RST          47
/**@brief Link ID out of range */
#define ELNRNG          48
/**@brief Protocol driver not attached */
#define EUNATCH         49
/**@brief No available CSI structure */
#define ENOCSI          50
/**@brief Level 2 halted */
#define EL2HLT          51
/**@brief Invalid exchange */
#define EBADE           52
/**@brief Invalid request descriptor */
#define EBADR           53
/**@brief Exchange full */
#define EXFULL          54
/**@brief No anode */
#define ENOANO          55
/**@brief Invalid request code */
#define EBADRQC         56
/**@brief Invalid slot */
#define EBADSLT         57
/**@brief Resource deadlock (the same value as {@link EDEADLK}) */
#define EDEADLOCK       EDEADLK
/**@brief Incorrect font format */
#define EBFONT          59
/**@brief Not a stream device */
#define ENOSTR          60
/**@brief No message is available on the stream head read queue */
#define ENODATA         61
/**@brief Timer expired */
#define ETIME           62
/**@brief No stream resources */
#define ENOSR           63
/**@brief Machine is disconnected from the network. */
#define ENONET          64
/**@brief Package not installed */
#define ENOPKG          65
/**@brief Object is remote */
#define EREMOTE         66
/**@brief Link has been severed */
#define ENOLINK         67
/**@brief Broadcast error */
#define EADV            68
/**@brief srmount error */
#define ESRMNT          69
/**@brief Communication error on send */
#define ECOMM           70
/**@brief Protocol error */
#define EPROTO          71
/**@brief Multi-hop attempt */
#define EMULTIHOP       72
/**@brief RFS-specific error */
#define EDOTDOT         73
/**@brief Non-data message */
#define EBADMSG         74
/**@brief Value too large to be represented by the defined data type */
#define EOVERFLOW       75
/**@brief Name not unique on the network */
#define ENOTUNIQ        76
/**@brief File descriptor in the bad state */
#define EBADFD          77
/**@brief Remote address changed */
#define EREMCHG         78
/**@brief Cannot access a needed shared library */
#define ELIBACC         79
/**@brief Accessing a corrupted shared library */
#define ELIBBAD         80
/**@brief lib section in a.out corrupted */
#define ELIBSCN         81
/**@brief Attempting to link in too many shared libraries */
#define ELIBMAX         82
/**@brief Cannot execute a shared library directly */
#define ELIBEXEC        83
/**@brief Invalid byte sequence */
#define EILSEQ          84
/**@brief Interrupted system call should be restarted */
#define ERESTART        85
/**@brief Stream pipe error */
#define ESTRPIPE        86
/**@brief Too many users */
#define EUSERS          87
/**@brief Not a socket */
#define ENOTSOCK        88
/**@brief Destination address required */
#define EDESTADDRREQ    89
/**@brief Message too long */
#define EMSGSIZE        90
/**@brief Socket protocol error */
#define EPROTOTYPE      91
/**@brief Protocol not available */
#define ENOPROTOOPT     92
/**@brief Protocol not supported */
#define EPROTONOSUPPORT 93
/**@brief Socket type not supported */
#define ESOCKTNOSUPPORT 94
/**@brief Operation not supported on socket */
#define EOPNOTSUPP      95
/**@brief Operation not supported on socket. The value is the same as that of {@link EOPNOTSUPP}. */
#define ENOTSUP         EOPNOTSUPP
/**@brief Protocol family not supported */
#define EPFNOSUPPORT    96
/**@brief Address family not supported */
#define EAFNOSUPPORT    97
/**@brief Address already in use */
#define EADDRINUSE      98
/**@brief Address not available */
#define EADDRNOTAVAIL   99
/**@brief Network is down */
#define ENETDOWN        100
/**@brief Network unreachable */
#define ENETUNREACH     101
/**@brief Network disconnection caused by restart */
#define ENETRESET       102
/**@brief Network disconnection caused by software problems */
#define ECONNABORTED    103
/**@brief Connection reset */
#define ECONNRESET      104
/**@brief No buffer space available */
#define ENOBUFS         105
/**@brief Socket is connected */
#define EISCONN         106
/**@brief Socket disconnected */
#define ENOTCONN        107
/**@brief Cannot send after transport endpoint shutdown */
#define ESHUTDOWN       108
/**@brief Cannot splice due to too many references */
#define ETOOMANYREFS    109
/**@brief Connection timed out */
#define ETIMEDOUT       110
/**@brief Connection refused */
#define ECONNREFUSED    111
/**@brief Host is down */
#define EHOSTDOWN       112
/**@brief Host is unreachable */
#define EHOSTUNREACH    113
/**@brief Operation already in process. */
#define EALREADY        114
/**@brief Operation in progress */
#define EINPROGRESS     115
/**@brief Stale file handle */
#define ESTALE          116
/**@brief Structure needs cleaning */
#define EUCLEAN         117
/**@brief Not a XENIX named type file */
#define ENOTNAM         118
/**@brief No XENIX semaphores available */
#define ENAVAIL         119
/**@brief Duplicate file name */
#define EISNAM          120
/**@brief Remote I/O error */
#define EREMOTEIO       121
/**@brief Quota exceeded */
#define EDQUOT          122
/**@brief No medium found */
#define ENOMEDIUM       123
/**@brief Wrong medium type */
#define EMEDIUMTYPE     124
/**@brief Operation canceled */
#define ECANCELED       125
/**@brief Required key not available */
#define ENOKEY          126
/**@brief Key has expired */
#define EKEYEXPIRED     127
/**@brief Key has been revoked */
#define EKEYREVOKED     128
/**@brief Key was rejected by service */
#define EKEYREJECTED    129
/**@brief Resource owner died */
#define EOWNERDEAD      130
/**@brief State not recoverable */
#define ENOTRECOVERABLE 131
/**@brief Operation not possible due to RF-kill */
#define ERFKILL         132
/**@brief Hardware errors on the memory page */
#define EHWPOISON       133

/** @} */