/**
* @addtogroup UTILS
* @{
*
* @brief Provides functions and data structures related to system operations, such as string conversion and I/O, string operations, process operations and so on.
*
* @since 1.0
* @version 1.0
*/

/**
* @file crypt.h
*
* @brief Encrypts data.
*
* You can use the functions provided in this file to encrypt data.
*
* @since 1.0
* @version 1.0
*/

#ifndef _CRYPT_H
#define _CRYPT_H

#ifdef __cplusplus
extern "C" {
#endif

/**
* @brief Encrypts data.
*
* This function converts the string to be encrypted to one-way hash data that can be stored in the user database. \n
* @attention The returned string is composed of printable ASCII characters, but does not contain spaces or any of the following characters: {':', ';', '*', '!', '\'}.
* @param key Indicates the data to be encrypted.
* @param setting Indicates the description of the encryption mode. The description consists of the encryption prefix and random characters, which are selected from (., /, 0-9, A-Z, a-z). The details are as follows:
* Encryption Algorithm | Encryption Prefix | Number of Random Characters
* ----------- | ------  |------------------------------------------------
*  SHA-2-512  |  '$6$'  |   16
*  SHA-2-256  |  '$5$'  |  16
*  MD5   |  '$1$'  |  8
*  DES    |  ''   |  2
* @return Returns the encrypted data if the operation is successful; returns <b>NULL</b> and sets <b>errno</b> to a value in the following table if the operation fails.
* Input | Error code
*  -------- | ---------
* <b>setting</b> is set to <b>NULL</b>. | {@link EINVAL}
* The hash password or encryption algorithm is not supported. | {@link ENOSYS}
* The system does not allow the encryption algorithm. | {@link EPERM}
* @since  1.0
* @version  1.0
*/
char *crypt(const char *key, const char *setting);

#ifdef __cplusplus
}
#endif

#endif
/** @} */