/**
* @addtogroup NET
* @{
*
* @brief Provides functions and data structures related to network operations.
*
* @since 1.0
* @version 1.0
*/

/**
* @file ifaddrs.h
*
* @brief Provides functions and data structures related to network operations.
*
* For example, you can use the functions to send and receive network data, manage network addresses, and convert bytes.
*
* @since 1.0
* @version 1.0
*/
#ifndef _IFADDRS_H
#define _IFADDRS_H

#ifdef __cplusplus
extern "C" {
#endif

#include <sys/socket.h>

/**
* @brief Defines the network interface information.
*/
struct ifaddrs {
/** Next item in the linked list */
struct ifaddrs *ifa_next;
/** Interface name */
char *ifa_name;
/** Interface flag */
unsigned ifa_flags;
/** Interface address */
struct sockaddr *ifa_addr;
/** Interface netmask */
struct sockaddr *ifa_netmask;
union {
/** Broadcast address associated with <b>ifa_addr</b> */
struct sockaddr *ifu_broadaddr;
/** Destination address of the point-to-point interface */
struct sockaddr *ifu_dstaddr;
} ifa_ifu;
/** Address-specific data */
void *ifa_data;
};

/**
* @brief Frees the network interface information obtained by {@link getifaddrs}.
*
* @param ifp Indicates the pointer to the network interface information to be freed.
* @since 1.0
* @version 1.0
*/
void freeifaddrs(struct ifaddrs *ifp);

#ifdef __cplusplus
}
#endif

#endif/** @} */