/**
* @addtogroup UTILS
* @{
*
* @brief Provides functions and data structures related to system operations, such as string conversion and I/O, string operations, process operations and so on.
*
* @since 1.0
* @version 1.0
*/

/**
* @file limits.h
*
* @brief Declares commonly used macro values.
*
* @since 1.0  \n
* @version 1.0  \n
*/

#ifndef _LIMITS_H
#define _LIMITS_H


#if '\xff' > 0
/**@brief Minimum value of type char */
#define CHAR_MIN 0
/* char类型的最小值 */

/**@brief Maximum value of type char */
#define CHAR_MAX 255
#else
/**@brief Minimum value of type char */
#define CHAR_MIN (-128)

/**@brief Maximum value of type char */
#define CHAR_MAX 127
#endif

/**@brief Number of bits in type char */
#define CHAR_BIT 8

/**@brief Minimum value of type signed char */
#define SCHAR_MIN (-128)

/**@brief Maximum value of type signed char */
#define SCHAR_MAX 127

/**@brief Maximum value of type unsigned char */
#define UCHAR_MAX 255

/**@brief Minimum value of type short */
#define SHRT_MIN  (-1-0x7fff)

/**@brief Maximum value of type short */
#define SHRT_MAX  0x7fff

/**@brief Maximum value of type unsigned short */
#define USHRT_MAX 0xffff

/**@brief Minimum value of type int */
#define INT_MIN  (-1-0x7fffffff)

/**@brief Maximum value of type int */
#define INT_MAX  0x7fffffff

/**@brief Maximum value of type unsigned int */
#define UINT_MAX 0xffffffffU

/**@brief Maximum value of type long */
#define __LONG_MAX 0x7fffffffL

/**@brief Minimum value of type long */
#define LONG_MIN (-LONG_MAX-1)

/**@brief Maximum value of type long */
#define LONG_MAX __LONG_MAX

/**@brief Maximum value of type unsigned long */
#define ULONG_MAX (2UL*LONG_MAX+1)

/**@brief Minimum value of type long long */
#define LLONG_MIN (-LLONG_MAX-1)

/**@brief Maximum value of type long long */
#define LLONG_MAX  0x7fffffffffffffffLL

/**@brief Maximum value of type unsigned long long */
#define ULLONG_MAX (2ULL*LLONG_MAX+1)

/**@brief Buffer length of pipe */
#define PIPE_BUF 4096

/**@brief Maximum length of file or directory name */
#define NAME_MAX 255

/**@brief Maximum length of the whole file or directory path */
#define PATH_MAX 256

/**@brief Maximum length of parameter arg */
#define ARG_MAX 4096

/**@brief Maximum vector number */
#define IOV_MAX 1024

/**@brief Number of bits in word */
#define WORD_BIT 32

/**@brief Maximum value of type ssize_t */
#define SSIZE_MAX LONG_MAX

/**@brief Maximum length of host name */
#define HOST_NAME_MAX 255

/**@brief Number of bits in long */
#define LONG_BIT 32

/**@brief Maximum priority number of message queue */
#define MQ_PRIO_MAX 1

/**@brief Page size */
#define PAGESIZE 4096

/**@brief Page size */
#define PAGE_SIZE PAGESIZE

#endif
/** @} */