/**
* @addtogroup UTILS
* @{
*
* @brief Provides functions and data structures related to system operations, such as string conversion and I/O, string operations, process operations and so on.
*
* @since 1.0
* @version 1.0
*/

/**
* @file monetary.h
*
* @brief Provides functions for converting monetary values.
*
* You can use the functions in the file to convert a group of monetary values into strings.
*
* @since 1.0
* @version 1.0
*/
#ifndef _MONETARY_H
#define _MONETARY_H

#ifdef __cplusplus
extern "C" {
#endif


/**
* @brief Converts a monetary value to a string.
*
* This function formats the monetary parameters according to a specified format and saves the results as a string. \n
* @attention For details about currency symbols, see {@link lconv}.
* @param s Indicates the pointer to the target string.
* @param max Indicates the maximum length of the target string.
* @param format Indicates the pointer to the format of the string.
* @param ... Indicates the parameters corresponding to the format.
* @return Returns number of bytes stored in the target string, excluding the terminating null byte <b>\0</b>, if the operation is successful; returns <b>-1</b> sets <b>errno</b> to {@link E2BIG} if the operation fails.
* @since 1.0
* @version 1.0
*/
ssize_t strfmon(char *s,   size_t max,   const char *format,   ...);

#ifdef __cplusplus
}
#endif

#endif

/** @} */