/**
* @addtogroup IO
* @{
*
* @brief Provides data structures and functions for performing input/output (I/O) operations, such as printf and scanf.
*
* @since 1.0
* @version 1.0
*/

/**
* @file poll.h
*
* @brief Declares I/O multiplexing functions.
*
* You can use the functions provided in this file to perform I/O multiplexing.
*
* @since 1.0
* @version 1.0
*/

#ifndef	 _POLL_H
#define	 _POLL_H

#ifdef __cplusplus
extern "C" {
#endif


/**@brief POLLIN event */
#define POLLIN     0x001
/**@brief POLLPRI event */
#define POLLPRI    0x002
/**@brief POLLOUT event */
#define POLLOUT    0x004
/**@brief POLLERR event */
#define POLLERR    0x008
/**@brief POLLHUP event */
#define POLLHUP    0x010
/**@brief POLLNVAL event */
#define POLLNVAL   0x020

/**@brief Number of poll types */
typedef unsigned long nfds_t;

/**
* @brief Defines I/O multiplexing.
*
* This structure is used to describe the content during I/O multiplexing, including the file descriptor, event mask, and returned event mask. \n
*/
struct pollfd {
/** File descriptor */
int fd;
/** Event mask to be queried */
short events;
/** Returned event mask */
short revents;
};

/**
* @brief Defines the I/O multiplexing system.
*
* This function is used to mount the pointer to the <b>pollfd</b> file to the waiting queue and then monitor the file. \n
* @param fds[] Indicates the <b>pollfd</b> array used to store the socket descriptor to be checked.
* @param nfds Indicates the <b>nfds_t</b> parameter used to mark the total number of structure elements in <b>fds</b>.
* @param timeout Indicates the blocking time, in milliseconds.
* @return Returns a value greater than 0 if the total number of socket descriptors in <b>fds</b> is ready for read or write, or on which errors occur; returns <b>0</b> otherwise, in which case <b>poll</b> timed out.
* Returns <b>-1</b> and sets <b>errno</b> to a value if this function fails to be called.
* @since 1.0
* @version 1.0
*/
int poll(struct pollfd fds[], nfds_t nfds, int timeout);

#ifdef __cplusplus
}
#endif

#endif

/** @} */