/**
* @addtogroup FS
* @{
*
* @brief Provides functions for file system, include file operations, directory operations and so on.
*
* @since 1.0
* @version 1.0
*/

/**
* @file ioctl.h
*
* @brief Manipulates a device.
*
* @since 1.0
* @version 1.0
*/

#ifndef	 _IOCTL_H
#define	 _IOCTL_H

#ifdef __cplusplus
extern "C" {
#endif

/**
* @brief Manipulates a device.
*
* This function is used to perform specified operations on an input device file descriptor. \n
* @param fd Indicates the file descriptor of the device (file-related file descriptors are not supported).
* @param cmd Indicates the operation instruction for the device. You can define it based on the specific device.
* @return Returns <b>0</b> if the operation is successful; returns <b>-1</b> and sets <b>errno</b> to a value in the following table otherwise.
* errno | Description
* --------- | -------------------------------
* EBADF | <b>fd</b> is an invalid file descriptor.
* EFAULT | An inaccessible memory area is referenced.
* EINVAL | The command request is invalid.
* ENOTTY | <b>fd</b> is not associated with a character special device.
* @since 1.0
* @version 1.0
*/
int ioctl(int fd, int cmd, ...);

#ifdef __cplusplus
}
#endif

#endif
/** @} */