/**
* @addtogroup IPC
* @{
*
* @brief Provides functions and structures related to inter-process communication (IPC), including signals, semaphores, and message queues.
*
* @since 1.0
* @version 1.0
*/

/**
* @file ipc.h
*
* @brief Defines IPC-related macros.
*
* @since 1.0
* @version 1.0
*/

#ifndef _SYS_IPC_H
#define _SYS_IPC_H
#ifdef __cplusplus
extern "C" {
#endif

#include <bits/ipcstat.h>

/** @brief Defines the input parameter used to create an IPC object. */
#define IPC_CREAT  01000
/** @brief Defines the input parameter used together with {@link IPC_CREAT} to prevent duplicate key values during IPC creation. */
#define IPC_EXCL   02000
/** @brief Defines the input parameter that specifies whether the communication is in non-blocking mode. */
#define IPC_NOWAIT 04000

/** @brief Defines the input parameter used to delete an IPC object. */
#define IPC_RMID 0
/** @brief Defines the input parameter used to set information to the kernel. */
#define IPC_SET  1
/** @brief Defines the input parameter used to obtain the system-level restriction information of a specified communication type, for example, {@link shminfo}. */
#define IPC_INFO 3
/** @brief Defines the IPC object as a private object. */
#define IPC_PRIVATE ((key_t) 0)

#ifdef __cplusplus
}
#endif
#endif
/** @} */