/**
* @addtogroup PROCESS
* @{
*
* @brief Provides process- and thread-related structures and functions.
*
* @since 1.0
* @version 1.0
*/

/**
* @file resource.h
*
* @brief Declares process-related structures and functions.
*
* @since 1.0
* @version 1.0
*/

#ifndef	 _SYS_RESOURCE_H
#define	 _SYS_RESOURCE_H

#ifdef __cplusplus
extern "C" {
#endif

#include <sys/time.h>

/**
* @brief Obtains the static priority of a specified ID.
*
* @param which Indicates a specified value. The values are as follows:
* value          | Description
* ---------------|------------------------------------------------------------------------------------------
* RIO_PROCESS    | <b>who</b> indicates the ID of a specified process.
* PRIO_PGRP      | <b>who</b> indicates the ID of a specified process group. This value is not supported yet.
* PRIO_USER      | <b>who</b> indicates the ID of a specified valid user. This value is not supported yet.
* @param who Indicates the specified ID.
* @return Returns the scheduling priority if the operation is successful; returns <b>-1</b> and sets <b>errno</b> to a value in the following table otherwise.
* errno | Description
* -------|---------------------------------------
* EINVAL | Invalid parameter.
* EOPNOTSUPP | Unsupported value.
* @since 1.0
* @version 1.0
*/
int getpriority(int which, id_t who);

/**
* @brief Sets the static priority of a specified ID.
*
* @param which Indicates a specified value. The values are as follows:
* value       | Description
* ------------|------------------------------------------------------------------------------------------
* RIO_PROCESS | <b>who</b> indicates the ID of a specified process.
* PRIO_PGRP   | <b>who</b> indicates the ID of a specified process group. This value is not supported yet.
* PRIO_USER   | <b>who</b> indicates the ID of a specified valid user. This value is not supported yet.
* @param who Indicates the specified ID.
* @param value Indicates the target priority to set.
* @return Returns the scheduling priority if the operation is successful; returns <b>-1</b> and sets <b>errno</b> to a value in the following table otherwise.
* errno | Description
* -------|---------------------------------------
* EINVAL | Invalid parameter.
* EPERM | The operation is not allowed.
* EOPNOTSUPP | Unsupported value.
* @since 1.0
* @version 1.0
*/
int setpriority(int which, id_t who, int value);

#ifdef __cplusplus
}
#endif
#endif

/** @} */