/**
* @addtogroup FS
* @{
*
* @brief Provides functions for file system, include file operations, directory operations and so on.
*
* @since 1.0
* @version 1.0
*/

/**
* @file statfs.h
*
* @brief Provides a function to obtain information about a file system.
*
* @since 1.0
* @version 1.0
*/
#ifndef	 _SYS_STATFS_H
#define	 _SYS_STATFS_H

#ifdef __cplusplus
extern "C" {
#endif


/**
* @brief Obtains file system information of a file in a specified path.
*
* @param path Indicates the pointer to the name of the target file.
* @param buf Indicates the pointer to a <b>statfs</b> structure that stores the information about the file system.
* @return Returns <b>0</b> if the operation is successful; returns <b>-1</b> and sets <b>errno</b> to a value in the following table if the operation fails.
* errno | Description
* ------------ | --------------------------------
* EACCES | Search permission is denied on a component of the path prefix.
* EFAULT | <b>buf</b> or <b>path</b> points to an invalid address.
* EINTR | The function call was interrupted by a signal.
* EIO | An I/O error occurred while reading from the file system.
* ELOOP | Too many symbolic links were found.
* ENAMETOOLONG | <b>path</b> is too long.
* ENOENT | The file referred to by <b>path</b> does not exist.
* ENOMEM | Insufficient memory.
* ENOSYS | The operation is not supported.
* ENOTDIR | A component of the path prefix of <b>path</b> is not a directory.
* EOVERFLOW | Information overflow
* @since 1.0
* @version 1.0
*/
int statfs(const char *path, struct statfs *buf);

#ifdef __cplusplus
}
#endif

#endif
/** @} */