/**
* @addtogroup FS
* @{
*
* @brief Provides functions for file system, include file operations, directory operations and so on.
*
* @since 1.0
* @version 1.0
*/

/**
* @file statvfs.h
*
* @brief Provides a function and structure related to file system information operation, for example, viewing file system information.
*
* @since 1.0
* @version 1.0
*/

#ifndef	 _SYS_STATVFS_H
#define	 _SYS_STATVFS_H


#ifdef __cplusplus
extern "C" {
#endif


#define __NEED_fsblkcnt_t
#define __NEED_fsfilcnt_t

/**
* @brief Describes file system information.
*/
struct statvfs {
/** File system block size */
unsigned long f_bsize;
/** Fragment size */
unsigned long f_frsize;
/** Size of <b>fs</b>, in units of <b>f_frsize</b> */
fsblkcnt_t f_blocks;
/** Free blocks */
fsblkcnt_t f_bfree;
/** Free blocks for unprivileged users */
fsblkcnt_t f_bavail;
/** File nodes (inodes) */
fsfilcnt_t f_files;
/** Free inodes */
fsfilcnt_t f_ffree;
/** Free inodes for unprivileged users */
fsfilcnt_t f_favail;
#if __BYTE_ORDER == __LITTLE_ENDIAN
/** File system ID */
unsigned long f_fsid;
unsigned :8*(2*sizeof(int)-sizeof(long));
#else
unsigned :8*(2*sizeof(int)-sizeof(long));
/** File system ID */
unsigned long f_fsid;
#endif
/** Mount flags */
unsigned long f_flag;
/** Maximum file name length */
unsigned long f_namemax;
/** Reserved */
int __reserved[6];
};

/**
* @brief Obtains the file system information.
*
* @param path Indicates the pointer to the path name of the file.
* @param buf Indicates the pointer to the <b>statvfs</b> structure that stores the obtained file system information.
* @return Returns <b>0</b> if the file system information is obtained successfully; returns <b>-1</b> and sets <b>errno</b> to a value in the following table otherwise.
* errno | Description
* ------------ | --------------------------------
* EACCES | Search permission is denied on a component of the path prefix.
* EFAULT | <b>buf</b> or <b>path</b> points to an invalid address.
* EINTR | This call was interrupted by a signal.
* EIO | An I/O error occurred while reading from the file system.
* ELOOP | Too many symbolic links were found.
* ENAMETOOLONG | <b>path</b> is too long.
* ENOENT | The file specified by <b>path</b> does not exist.
* ENOMEM | Insufficient memory.
* ENOSYS | The file system does not support this call.
* ENOTDIR | A component of the path prefix of <b>path</b> is not a directory.
* EOVERFLOW | Information overflows.
* @since 1.0
* @version 1.0
*/
int statvfs(const char *__restrict path, struct statvfs *__restrict buf);

#ifdef __cplusplus
}
#endif

#endif
/** @} */