/**
* @addtogroup TIME
* @{
*
* @brief Provides time-related structures and functions.
*
* @since 1.0
* @version 1.0
*/

/**
* @file timeb.h
*
* @brief Provides structures and functions related to the curren time.
*
* You can obtain the current time.
*
* @since 1.0
* @version 1.0
*/
#ifndef _SYS_TIMEB_H
#define _SYS_TIMEB_H
#ifdef __cplusplus
extern "C" {
#endif


/**
* @brief Describes the time, accurate to millisecond.
*
*/
struct timeb {
/** Total number of seconds elapsed since January 1, 1970 00:00:00 (UTC) */
time_t time;
/** Number of milliseconds in the current time */
unsigned short millitm;
/** Time zone */
short timezone;
/** Whether DST is observed */
short dstflag;
};

/**
* @brief Obtains the current time, accurate to milliseconds.
*
* The time obtained is the total number of milliseconds elapsed since January 1, 1970 00:00:00 (UTC). \n
* @param tp Indicates the pointer to the number of milliseconds. <b>timezone</b> and <b>dstflag</b> are set to <b>0</b>.
* @return Returns <b>0</b> if the operation is successful; returns <b>-1</b> otherwise.
* @since 1.0
* @version 1.0
*/
int ftime(struct timeb *tp);

#ifdef __cplusplus
}
#endif
#endif/** @} */