/**
* @addtogroup TIME
* @{
*
* @brief Provides time-related structures and functions.
*
* @since 1.0
* @version 1.0
*/

/**
* @file times.h
*
* @brief Provides structures and functions related to the process time.
*
* You can obtain the process time.
*
* @since 1.0
* @version 1.0
*/
#ifndef	 _SYS_TIMES_H
#define	 _SYS_TIMES_H

#ifdef __cplusplus
extern "C" {
#endif


/**
* @brief Describes CPU time of a process and its child processes.
*
*
*/
struct tms {
/** User time */
clock_t tms_utime;
/** System time */
clock_t tms_stime;
/** Child process's user time*/
clock_t tms_cutime;
/** Child process's system time*/
clock_t tms_cstime;
};

/**
* @brief Obtains the number of clock ticks of the current process.
*
* @param tm Indicates the pointer to the <b>tms</b> structure that contains the clock ticks, which can be <b>NULL</b>.
* @return Returns the number of clock ticks of CPU 0.
* @since 1.0
* @version 1.0
*/
clock_t times(struct tms *tm);

#ifdef __cplusplus
}
#endif

#endif
/** @} */
