/**
* @addtogroup FS
* @{
*
* @brief Provides functions for file system, include file operations, directory operations and so on.
*
* @since 1.0
* @version 1.0
*/

/**
* @file utime.h
*
* @brief Provides the function and structure used for setting file access time and modification time.
*
* @since 1.0
* @version 1.0
*/

#ifndef	 _UTIME_H
#define	 _UTIME_H

#ifdef __cplusplus
extern "C" {
#endif

#define __NEED_time_t

/**
* @brief Defines the file access time and modification time.
*/
struct utimbuf {
/** File access time: the last time the file was accessed */
time_t actime;
/** File modification time: the last time the file was modified */
time_t modtime;
};

/**
* @brief Sets the access time and modification time of a file.
*
* @param filename Indicates the pointer to the name of the file whose access time and modification time need to be set.
* @param times Indicates the pointer to the time to which the access time and modification time are set. If <b>times</b> is a null pointer, then the access time and modification time are set to the current time.
* @return Returns <b>0</b> if the access time and modification time are set successfully; returns <b>-1</b> and sets <b>errno</b> to a value in the following table otherwise.
* errno | Description
* ------------ | --------------------------------
* EINVAL | <b>filename</b> is null or <b>times</b> is invalid.
* ENAMETOOLONG | The length of the component in the path name is greater than the value of {@link NAME_MAX}.
* ENOENT | Some paths do not exist.
* ENOSYS | This function is not supported.
* EACCES | The file system is read-only.
* ENOMEM | Insufficient memory.
* EIO | A hardware error occurs at the underlying disk I/O layer.
* @since 1.0
* @version 1.0
*/
int utime(const char *filename, const struct utimbuf *times);

#ifdef __cplusplus
}
#endif

#endif
/** @} */